MethodChannelOpenSettingsPlus class

An implementation of OpenSettingsPlusPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessageToNative(String message) → Future<bool>
Method used to pass custom message to native side. This way we can pass any message to native side and handle it there. Note: android and ios have different implementation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited