sendMessageToNative method
Method used to pass custom message to native side. This way we can pass any message to native side and handle it there. Note: android and ios have different implementation.
Implementation
@override
Future<bool> sendMessageToNative(String message) async {
final success = await methodChannel.invokeMethod<bool>('openSettings', {
'settingToOpen': message,
});
return success ?? false;
}