OpenSettingsPlus class

Singleton used to create a OpenSettingsPlus instance. You can get iOS or android instance of OpenSettingsPlus using this class.

Implementers

Constructors

OpenSettingsPlus()
Singleton used to create a OpenSettingsPlus instance. You can get iOS or android instance of OpenSettingsPlus using this class.
const
OpenSettingsPlus.android()
Returns a singleton instance of OpenSettingsPlus for android.
const
factory
OpenSettingsPlus.iOS()
Returns a singleton instance of OpenSettingsPlus for iOS.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCustomMessage(String message) → Future<bool>
Method used to pass custom message to native side.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

shared → OpenSettingsPlus?
Singleton instance of OpenSettingsPlus. You can use this instance to open settings in iOS or android.
final

Static Methods

build() → OpenSettingsPlus?